pub struct FcmClient { /* private fields */ }Expand description
Firebase Cloud Messaging (FCM) client.
Implementations
Sourceimpl FcmClient
impl FcmClient
Sourcepub async fn send(
&self,
message: Message,
) -> Result<FcmSuccessResponse, FcmError>
pub async fn send( &self, message: Message, ) -> Result<FcmSuccessResponse, FcmError>
Sends an FCM message.
This method constructs and sends an HTTP request to the FCM API to deliver a message to the specified recipients. It handles authentication, constructs the necessary request, and processes the response from the FCM service.
Arguments
message- TheMessageto send.
Errors
Returns an FcmError if there’s an issue with the request, authentication,
JSON (de)serialization, the response, or any other error during the sending process.